[![Multi-Modality](agorabanner.png)](https://discord.gg/qUtxnK2NMf)

# Multi-Modal Causal Attention
The open source community's implementation of the all-new Multi-Modal Causal Attention from "DeepSpeed-VisualChat: Multi-Round Multi-Image Interleave Chat via Multi-Modal Causal Attention"


[Paper Link](https://arxiv.org/pdf/2309.14327.pdf)

# Appreciation
* Lucidrains
* Agorians



# Install

# Usage

# Architecture

# Todo


# License
MIT

# Citations

